@@ -136,10 +136,10 @@ extern double log10(double x);
 
 // #define _DEBUG_DLS
 
-#define DLS_MAX_WAVE_COUNT      1024
-#define DLS_MAX_ART_COUNT       2048
-#define DLS_MAX_REGION_COUNT    2048
-#define DLS_MAX_INST_COUNT      256
+#define DLS_MAX_WAVE_COUNT      2048
+#define DLS_MAX_ART_COUNT       4096
+#define DLS_MAX_REGION_COUNT    4096
+#define DLS_MAX_INST_COUNT      512
 #define MAX_DLS_WAVE_SIZE       (1024*1024)
 
 #ifndef EAS_U32_MAX
@@ -1613,7 +1613,17 @@ static EAS_RESULT Parse_insh (SDLS_SYNTHESIZER_DATA *pDLSData, EAS_I32 pos, EAS_
     if (bank & 0x7fff8080)
     {
         { /* dpp: EAS_ReportEx(_EAS_SEVERITY_WARNING, "DLS bank number is out of range: %08lx\n", bank); */ }
-        bank &= 0xff7f;
+    }
+    if (bank & 0x80000000u)
+    {
+        /* drum instrument */
+        bank &= 0x7f7f;
+        bank |= 0x10000;
+    }
+    else
+    {
+        /* melodic instrument */
+        bank &= 0x7f7f;
     }
     if (program > 127)
     {
